==> zio-aws-redshift_3-5.17.104.5-sources.jar: zio/aws/redshift/model/EnableSnapshotCopyResponse.scala <==
package zio.aws.redshift.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class EnableSnapshotCopyResponse(
    cluster: Option[zio.aws.redshift.model.Cluster] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.EnableSnapshotCopyResponse = {
    import EnableSnapshotCopyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.EnableSnapshotCopyResponse
      .builder()
      .optionallyWith(cluster.map(value => value.buildAwsValue()))(_.cluster)
      .build()
  }
  def asReadOnly: zio.aws.redshift.model.EnableSnapshotCopyResponse.ReadOnly =
    zio.aws.redshift.model.EnableSnapshotCopyResponse.wrap(buildAwsValue())
}
object EnableSnapshotCopyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.EnableSnapshotCopyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.EnableSnapshotCopyResponse =
      zio.aws.redshift.model
        .EnableSnapshotCopyResponse(cluster.map(value => value.asEditable))
    def cluster: Option[zio.aws.redshift.model.Cluster.ReadOnly]
    def getCluster
        : ZIO[Any, AwsError, zio.aws.redshift.model.Cluster.ReadOnly] =
      AwsError.unwrapOptionField("cluster", cluster)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.EnableSnapshotCopyResponse
  ) extends zio.aws.redshift.model.EnableSnapshotCopyResponse.ReadOnly {
    override val cluster: Option[zio.aws.redshift.model.Cluster.ReadOnly] =
      scala
        .Option(impl.cluster())
        .map(value => zio.aws.redshift.model.Cluster.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.EnableSnapshotCopyResponse
  ): zio.aws.redshift.model.EnableSnapshotCopyResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-redshift_3-6.20.69.2-sources.jar: zio/aws/redshift/model/EnableSnapshotCopyResponse.scala <==
package zio.aws.redshift.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class EnableSnapshotCopyResponse(
    cluster: Optional[zio.aws.redshift.model.Cluster] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.EnableSnapshotCopyResponse = {
    import EnableSnapshotCopyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.EnableSnapshotCopyResponse
      .builder()
      .optionallyWith(cluster.map(value => value.buildAwsValue()))(_.cluster)
      .build()
  }
  def asReadOnly: zio.aws.redshift.model.EnableSnapshotCopyResponse.ReadOnly =
    zio.aws.redshift.model.EnableSnapshotCopyResponse.wrap(buildAwsValue())
}
object EnableSnapshotCopyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.EnableSnapshotCopyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.EnableSnapshotCopyResponse =
      zio.aws.redshift.model
        .EnableSnapshotCopyResponse(cluster.map(value => value.asEditable))
    def cluster: Optional[zio.aws.redshift.model.Cluster.ReadOnly]
    def getCluster
        : ZIO[Any, AwsError, zio.aws.redshift.model.Cluster.ReadOnly] =
      AwsError.unwrapOptionField("cluster", cluster)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.EnableSnapshotCopyResponse
  ) extends zio.aws.redshift.model.EnableSnapshotCopyResponse.ReadOnly {
    override val cluster: Optional[zio.aws.redshift.model.Cluster.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.cluster())
        .map(value => zio.aws.redshift.model.Cluster.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.EnableSnapshotCopyResponse
  ): zio.aws.redshift.model.EnableSnapshotCopyResponse.ReadOnly = new Wrapper(
    impl
  )
}
